CallbackWidgetBuilder<T> typedef

CallbackWidgetBuilder<T> = Widget Function(T value)

Signature for a function that creates a widget for a given value of type T.

Used for scenarios where a widget needs to be built from a single value, such as mapping a data model to a widget.

See also:

Implementation

typedef CallbackWidgetBuilder<T> = Widget Function(T value);